@@ -128,6 +128,8 @@ class TlmsWmsEntDirect(models.Model):
     transaction_mode = models.CharField(max_length=50, verbose_name="成交方式", help_text="成交方式", null=True, blank=True)
     est_arrival_time = models.DateField(verbose_name="预计到港日期", help_text="预计到港日期", null=True, blank=True)
     arrival_time = models.DateField(verbose_name="到港日期", help_text="到港日期", null=True, blank=True)
+    sender = models.CharField(max_length=100, verbose_name="发货人", null=True, blank=True)
+    receiver = models.CharField(max_length=100, verbose_name="收货人", null=True, blank=True)
     # wms
     remark = models.CharField(max_length=200, verbose_name="备注", help_text="备注", null=True, blank=True)
     plan_ent_date = models.DateTimeField(verbose_name="出入库时间")
@@ -228,13 +230,15 @@ class TlmsWmsEntCtn(models.Model):
     id = TlmsWmsEntCtnIdField(max_length=18, primary_key=True, auto_created=True, editable=False)
     ent_direct = models.ForeignKey(TlmsWmsEntDirect, on_delete=models.CASCADE, related_name='ent_direct_ctn',
                                  verbose_name="订单号", help_text="订单号")
-    ctnno = models.CharField(max_length=30, verbose_name="箱号", help_text="箱号")
-    ctn_size = models.ForeignKey(CtnSize, on_delete=models.CASCADE, related_name='ent_direct_ctn_size', verbose_name="箱尺寸", help_text="箱尺寸")
-    ctn_type = models.ForeignKey(CtnType, on_delete=models.CASCADE, related_name='ent_direct_ctn_type', verbose_name="箱类型", help_text="箱类型")
+    ctnno = models.CharField(max_length=30, null=True, blank=True, verbose_name="箱号", help_text="箱号")
+    ctn_size = models.ForeignKey(CtnSize, null=True, blank=True, on_delete=models.CASCADE, related_name='ent_direct_ctn_size', verbose_name="箱尺寸", help_text="箱尺寸")
+    ctn_type = models.ForeignKey(CtnType, null=True, blank=True, on_delete=models.CASCADE, related_name='ent_direct_ctn_type', verbose_name="箱类型", help_text="箱类型")
     seal_no = models.CharField(max_length=30, verbose_name="铅封号", help_text="铅封号", null=True, blank=True)
     gross_weight = models.DecimalField(verbose_name="箱毛重", help_text="箱毛重", default=0, max_digits=19,
                                        decimal_places=5)
     remark = models.CharField(max_length=200, verbose_name="备注", help_text="备注", null=True, blank=True)
+    car_code = models.CharField(verbose_name="车牌号", max_length=20, null=True, blank=True)
+    one_car_two_ctn = models.BooleanField(default=False, verbose_name="一车双箱")
 
     class Meta:
         verbose_name = "委托业务箱子明细"
