@@ -30,8 +30,8 @@ class CargoListViewSet(FalseDeleteModelViewSet):
     serializer_class = serializer.CargoSerializer
     pagination_class = CargoPageSetPagination
     filter_backends = (DjangoFilterBackend, filters.SearchFilter, filters.OrderingFilter)
-    search_fields = ['name']  # SearchFilter: like模糊搜索, query params为"search"，与search_fields配合使用
-    ordering_fields = ['name']
+    search_fields = ['name', 'id', 'code', 'hs_code']  # SearchFilter: like模糊搜索, query params为"search"，与search_fields配合使用
+    ordering_fields = ['name','id', 'code', 'hs_code']
 
 
 class ConsignorViewSet(FalseDeleteModelViewSet):
